@@ -36,7 +36,7 @@ from gi.repository import GLib
 
 from dashio.device import Device
 
-from .constants import CONNECTION_PUB_URL, DEVICE_PUB_URL
+from .constants import CONNECTION_PUB_URL
 
 
 class BLEControl():
@@ -199,18 +199,25 @@ class NotPermittedException(dbus.exceptions.DBusException):
 class BLEConnection(dbus.service.Object, threading.Thread):
     """BLEConnection
     """
+    def _send_announce(self):
+        msg = {
+            'msgType': 'send_announce',
+            'connectionUUID': self.zmq_connection_uuid
+        }
+        #  logging.debug("TCP SEND ANNOUNCE: %s", msg)
+        self.tx_zmq_pub.send_multipart([b"COMMAND", json.dumps(msg).encode()])
 
     def add_device(self, device: Device):
         """Add a device to the connection
 
         Parameters
         ----------
-        device : Device
-            The device to add
+        device : dashio.Device
+            Add a device to the connection.
         """
-        device._add_connection(self)
-        self.rx_zmq_sub.connect(DEVICE_PUB_URL.format(id=device.zmq_connection_uuid))
-        # self.rx_zmq_sub.setsockopt_string(zmq.SUBSCRIBE, device.zmq_pub_id)
+        if device.device_id not in self.local_device_id_list:
+            device.register_connection(self)
+            self.local_device_id_list.append(device.device_id)
 
     def close(self):
         """Close the connection
@@ -225,11 +232,12 @@ class BLEConnection(dbus.service.Object, threading.Thread):
 
         while self.rx_zmq_sub.getsockopt(zmq.EVENTS) & zmq.POLLIN:
             try:
-                [_, _, data] = self.rx_zmq_sub.recv_multipart()
+                [msg_to, data] = self.rx_zmq_sub.recv_multipart()
             except ValueError:
                 continue
             if not data:
                 continue
+
             data_str = data.decode('utf-8')
             # TODO: need to set this for the negitiated MTU
             # 160 seems to work with iPhone
@@ -245,7 +253,9 @@ class BLEConnection(dbus.service.Object, threading.Thread):
         return True
 
     def _ble_rx(self, msg: str):
-        self.tx_zmq_pub.send_multipart([self.b_connection_id, b'1', msg.encode('utf-8')])
+        msg_from = self.b_connection_id
+        #  logging.debug("BLE ZMQ TX: %s", msg)
+        self.tx_zmq_pub.send_multipart([msg.encode(), msg_from])
 
     def __init__(self, ble_uuid=None, context: zmq.Context = None):
         """BLE Connection
@@ -261,10 +271,12 @@ class BLEConnection(dbus.service.Object, threading.Thread):
 
         self.zmq_connection_uuid = "BLE:" + shortuuid.uuid()
         self.b_connection_id = self.zmq_connection_uuid.encode('utf-8')
-
+        self.local_device_id_list = []
         self.context = context or zmq.Context.instance()
         self.rx_zmq_sub = self.context.socket(zmq.SUB)
-        self.rx_zmq_sub.setsockopt(zmq.SUBSCRIBE, b"ALL")
+        self.rx_zmq_sub.setsockopt_string(zmq.SUBSCRIBE, "ALL")
+        self.rx_zmq_sub.setsockopt_string(zmq.SUBSCRIBE, "COMMAND")
+        self.rx_zmq_sub.setsockopt_string(zmq.SUBSCRIBE, "BLE")
         self.rx_zmq_sub.setsockopt_string(zmq.SUBSCRIBE, self.zmq_connection_uuid)
         # TODO: Need to figure out why this doesn't work
         # GLib.io_add_watch(
@@ -327,9 +339,10 @@ class BLEConnection(dbus.service.Object, threading.Thread):
     def _register(self):
         adapter = self._find_adapter(self.bus)
         service_manager = dbus.Interface(self.bus.get_object(BLUEZ_SERVICE_NAME, adapter), GATT_MANAGER_IFACE)
-        service_manager.RegisterApplication(self._get_path(), {}, reply_handler=self._register_app_callback, error_handler=self._register_app_error_callback)
+        service_manager.RegisterApplication(self.get_path(), {}, reply_handler=self._register_app_callback, error_handler=self._register_app_error_callback)
 
     def run(self):
+        self._send_announce()
         self.mainloop.run()
 
 
