@@ -175,6 +175,19 @@ class ControlConfig:
         """
         return self.cfg
 
+    def update_position(self, control_position: ControlPosition):
+        """Updates the controls position from control_position
+
+        Parameters
+        ----------
+        control_position : ControlPosition
+            The position to use to update the control
+        """
+        self.cfg["xPositionRatio"] = control_position.x_position_ratio
+        self.cfg["yPositionRatio"] = control_position.y_position_ratio
+        self.cfg["widthRatio"] = control_position.width_ratio
+        self.cfg["heightRatio"] = control_position.height_ratio
+
     def __init__(
         self,
         control_id: str,
@@ -267,12 +280,11 @@ class Control():
             for cfg in self._cfg_full_page:
                 cfg_list.append(f"\tCFG\t{dashboard_id}\t{self.cntrl_type}\t{cfg.get_cfg_json()}")
         else:
-            logging.debug("Len: %s", len(self._cfg_columnar))
             for control_cfg in self._cfg_columnar:
                 cfg_list.append(f"\tCFG\t{dashboard_id}\t{self.cntrl_type}\t{control_cfg.get_cfg_json()}")
         return cfg_list
 
-    def get_cfg64(self, data) -> dict:
+    def get_cfg64(self, data) -> list:
         """Returns the CFG dict for the control called when the iotdashboard app asks for a CFG
 
         Parameters
@@ -289,7 +301,7 @@ class Control():
         try:
             num_columns = int(data[3])
         except (IndexError, ValueError):
-            return ""
+            return []
         if num_columns >= self._cfg_full_page_no_columns and self._cfg_full_page:
             for cfg in self._cfg_full_page:
                 cfg_list.append(cfg.get_cfg64())
@@ -337,12 +349,6 @@ class Control():
             The type of control to implement
         control_id : str
             An unique control identity string. The control identity string must be a unique string for each control per device
-        title : str, optional
-            Title of the control, by default None
-        control_position : ControlPosition, optional
-            The position of the control on a DeviceView this sets for number of columns = 1, by default None
-        title_position : TitlePosition, optional
-            Position of the title when displayed on the iotdashboard app, by default None
         """
         # Dictionary to store CFG json
         self._cfg_columnar = []
